#include "ti86asm.inc"

.org _asm_exec_ram

    call _flushallmenus        ; close any open menus
    call _runindicoff          ; turn off the run indicator
    
    
;-----------------------------------------------------------------
;thanks to David Phillips for the bitmap conversion program
;I used it in my cover page
;displays my coverpage


 ld hl,Pic                  ; point to RLE picture to display
 ld de,$fc00                ; display picture in video memory
 call DispRLE               ; decode and display the picture

 call _getkey               ; wait for a key to be pressed
 call _clrLCD               ; clear the display
 call _homeup
 jp Start                           ; move cursor to upper-left and exit

#include "Rle.asm"          ; include RLE picture displayer

Pic:
#include "Cover.asm"      ; RLE picture made by RLE2PIC


;--------------------------------------------------------------------------------
;--------------------------------------------------------------------------------
;; entering program

;in this program, "a" tells which page should be displayed


Start:
           
    ld hl,aHelp
    call _puts
    call _getkey
    ld a,1                                      




tester:             ; tests what a is on.
    call _clrScrn   ;need to clear screen now, because clrScrn would destroy hl (which will point to the text later)
    call _homeup    ; top left


    cp 1            ;is a on page one?          
    jp z,One        ; if so, jump to One
    cp 2
    jp z,Two
    cp 3
    jp z,Three
    cp 4
    jp z,Four
    cp 5
    jp z,Five
    cp 6
    jp z,Six
    cp 7
    jp z,Seven
    cp 8
    jp z,Eight
    cp 9
    jp z,Nine
    cp 10
    jp z,Ten
    cp 11
    jp z,Eleven
    cp 12
    jp z,Twelve
    cp 13
    jp z,Thirteen
    cp 14
    jp z,Fourteen
    cp 15
    jp z,Fifteen
    cp 16
    jp z,Sixteen
    cp 17
    jp z,Seventeen
    cp 18
    jp z,Eighteen
    cp 19
    jp z,Nineteen
    cp 20
    jp z,Twenty
    cp 21
    jp z,Twentyone
    cp 22
    jp z,Twentytwo
    cp 23
    jp z,Twentythree
    cp 24
    jp z,Twentyfour
    cp 25
    jp z,Twentyfive
    ld a,1              ;if not any of those, it must be 26, so we'll reset it (by going back to page 1)
    jp tester        

;start of the loader labels
indexdisplay1:
    call Clear
    ld a,1
    ld hl,aIndex1
    jp Displayer
indexdisplay2:
    call Clear
    ld a,8
    ld hl,aIndex2
    jp Displayer
indexdisplay3:
    call Clear
    ld a,15
    ld hl,aIndex3
    jp Displayer
indexdisplay4:
    call Clear
    ld a,22
    ld hl,aIndex4
    jp Displayer


One:
    ld hl,a1        ;page one, so load that adress into hl
    jp Displayer    ;jump to displayer to put it
Two:
    ld hl,a2
    jp Displayer
Three:
    ld hl,a3
    jp Displayer
Four:
    ld hl,a4
    jp Displayer
Five:
    ld hl,a5
    jp Displayer
Six:
    ld hl,a6
    jp Displayer
Seven:
    ld hl,a7
    jp Displayer
Eight:
    ld hl,a8
    jp Displayer
Nine:
    ld hl,a9
    jp Displayer
Ten:
    ld hl,a10
    jp Displayer
Eleven:
    ld hl,a11
    jp Displayer
Twelve:
    ld hl,a12
    jp Displayer
Thirteen:
    ld hl,a13
    jp Displayer
Fourteen:
    ld hl,a14
    jp Displayer
Fifteen:
    ld hl,a15
    jp Displayer
Sixteen:
    ld hl,a16
    jp Displayer
Seventeen:
    ld hl,a17
    jp Displayer
Eighteen:
    ld hl,a18
    jp Displayer
Nineteen:
    ld hl,a19
    jp Displayer
Twenty:
    ld hl,a20
    jp Displayer
Twentyone:
    ld hl,a21
    jp Displayer
Twentytwo:
    ld hl,a22
    jp Displayer
Twentythree:
    ld hl,a23
    jp Displayer
Twentyfour:
    ld hl,a24
    jp Displayer
Twentyfive:
    ld hl,a25
    jp Displayer


;displayer area

Displayer:
    ;right now, the screen is cleared, and hl points to text
    ;a still tells us what page number we're on   
    call _puts ;puts the text
    
;the following puts a in a safe place a getkey routine is run
    ld b,a      ;b=a



;destroys a and a bunch of other stuff?
;now we wait for a key
getkeyroutine:
    call _getkey    ;a has key
    cp kUp          ;compare to up
    jp z,oneback    ;ifthey're equal, go to oneback
    cp kDown        ;et al
    jp z,oneforward
    cp kExit
    jp z,Exit          
    cp k1
    jp z,indexdisplay1    
    cp k2
    jp z,indexdisplay2    
    cp k3
    jp z,indexdisplay3
    cp k4
    jp z,indexdisplay4
    jp getkeyroutine ;if not up, down, exit, or any of the indexes, then get another key
oneback:
    call Aftergetkey    ;a now points to page
    dec a               ;a points to one page back
    cp 0                ;if a is all the way back to page 0, then...
    jp z,nonegative     ;jump to nonegative to put 25 back into it and jump to tester, otherwise...
    jp tester           ;figure out what page it is and display it

oneforward:
    call Aftergetkey    ;a points to page

    
    inc a               ;one page forward
    jp tester           ;determine what page I'm on


Clear:
    call _clrScrn
    call _homeup
    ret




Exit:                   ;closes out program 
    call _clrScrn
    call _homeup
    ret    

Aftergetkey:
                 ;restoring bc
    ld a,b      ;b=a, so a now points to page
    ret
nonegative:
    ld a,25
    jp tester   
    


aHelp
    .db "Use [Up] and [Down]  "
    .db "  arrows to move     "
    .db "---------------------"
    .db "Press numbers 1-4 to "
    .db "  view the index     "
    .db "---------------------"
    .db "Press [Exit] to Quit",0




aIndex1:                                 ;page zero
    .db "      INDEX 1        "
    .db "1:MOSES 1:39         "
    .db "2:MOSES 7:18         "
    .db "3:Abraham 3:22-23    "
    .db "4:Genesis 1:26-27    "
    .db "5:Genesis 39:9       "
    .db "6:Exodus 20:3-17     "
    .db "7:Exodus 33:11",0
aIndex2:
    .db "     Index 2         "      
    .db "8:Leviticus 19:18    "
    .db "9:Deuteronomy 7:3-4  "
    .db "10:Joshua 1:8        "
    .db "11:Joshua 24:15      "
    .db "12:1 Samuel 16:7     "
    .db "13:Job 19:25-26      "
    .db "14:Psalms 24:3-4",0
aIndex3:
    .db "      Index 3        ",0
aIndex4:
    .db "      Index 4        ",0   




a1:
    .db "1'For behold, this is"
    .db "my work and my glory:"
    .db "to bring to pass the "
    .db "immortality and      "
    .db "eternal life of man'",0
a2:
    .db "2'And the lord called"
    .db "his peopl Zion,      "
    .db "because they were of "
    .db "one heart and one    "
    .db "mind and dwelt in    "
    .db "righteousness and    "
    .db "there was no poor    "
    .db "among them.'",0
a3:
    .db "3'Now the Lord had   " 
    .db "shown unto me,       " 
    .db "Abraham, the         "        
    .db "intelligences that   "
    .db "were organized before"
    .db "the world was; and   "
    .db "among all these there"
    .db "were many of the",0
a4:
    .db "noble and great ones;"
    .db "And God saw these    "  
    .db "souls that they were "
    .db "good, and he stood in"
    .db "the midst of them,   "
    .db "and he said: These I "
    .db "will make my rulers; "
    .db "for he stood among",0
a5:    
    .db "those that were      "
    .db "spirits, and he saw  "
    .db "that they were good; "
    .db "and he said unto me: "
    .db "Abraham, thou art one"
    .db "of them; thou wast   "
    .db "chosen before thou   "
    .db "wast born.'",0

a6:
    .db "4'And God said, Let  "  
    .db "us make man in our   "
    .db "image, after our     " 
    .db "likeness: and let    "
    .db "them have dominion   " 
    .db "over the fish of the "
    .db "sea, and over the    " 
    .db "fowl of the air, and",0
a7:
    .db "over the cattle, and "
    .db "over all the earth,  "
    .db "and over every       "
    .db "creeping thing that  "
    .db "creepeth upon the    "
    .db "earth.               " 
    .db "So God created man in"
    .db "his own image, in",0
a8:
    .db "the image of God     "
    .db "created he him; male "
    .db "and female created he"
    .db "them.'",0




a9:
    .db "5'There is none      " 
    .db "greater in this house"
    .db "than I; neither hath "
    .db "he kept back any     "
    .db "thing from me but    "
    .db "thee, because thou   "
    .db "art his wife: how    "
    .db "then can I do this",0
a10:
    .db "great wickedness, and" 
    .db "sin against God?",0


a11:
    .db "11",0
a12:
    .db "12",0
a13:
    .db "13",0
a14:
    .db "14",0
a15:
    .db "15",0
a16:
    .db "16",0
a17:
    .db "17",0
a18:
    .db "18",0
a19:
    .db "19",0
a20:
    .db "20",0
a21:
    .db "21",0
a22:
    .db "22",0
a23:
    .db "23",0
a24:
    .db "24",0
a25:
    .db "25",0








.end